#' Remove back-to-back duplicates of a pattern in a string.
#'
#' See [strex::str_singleize()].
#'
#' @inheritParams strex::str_singleize
#'
#' @export
singleize <- strex::str_singleize

#' @rdname singleize
#' @export
str_singleize <- singleize
